FirebaseMessagingHandlerWindows class
Windows platform registration stub for firebase_messaging_handler.
Firebase Cloud Messaging is not available on Windows, but the package
supports local features (scheduling, inbox, in-app templates, quiet hours)
via flutter_local_notifications and pure-Dart implementations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void